==> vdcpy-0.0.10.tar.gz: vdcpy-0.0.10/vdcpy/site.py <==
import requests

import vdcpy.config as config


def get_sites(
    site_id=None, name=None, description=None, logo=None, host=None,
    slots=None, hub=None, type=None, gpu=None, osg=None, alluxio=None):
    """
    Get a list of sites from the VDC API.

    Parameters
    ----------
    site_id : str
        The ID of the site to retrieve.
    name : str
        The name of the site to retrieve.
    description : str
        The description of the site to retrieve.
    logo : str
        The logo of the site to retrieve.
    host : str
        The host of the site to retrieve.
    slots : str
        The slots of the site to retrieve.
    hub : str
        The hub of the site to retrieve.
    type : str
        The type of the site to retrieve.
    gpu : str
        The GPU of the site to retrieve.
    osg : str
        The OSG of the site to retrieve.
    alluxio : str
        The alluxio of the site to retrieve.
    
    Returns
    -------
    site_list : list
        A list of sites.
    """
    site_list = []
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}'
    if site_id is not None:
        query += f'?id={site_id}'
    if name is not None:
        if site_id is None:
            query += f'?name={name}'
        else:
            query += f'&name={name}'
    if description is not None:
        if site_id is None and name is None:
            query += f'?description={description}'
        else:
            query += f'&description={description}'
    if logo is not None:
        if site_id is None and name is None and description is None:
            query += f'?logo={logo}'
        else:
            query += f'&logo={logo}'
    if host is not None:
        if site_id is None and name is None and description is None \
            and logo is None:
            query += f'?host={host}'
        else:
            query += f'&host={host}'
    if slots is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None:
            query += f'?slots={slots}'
        else:
            query += f'&slots={slots}'
    if hub is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None:
            query += f'?hub={hub}'
        else:
            query += f'&hub={hub}'
    if type is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None:
            query += f'?type={type}'
        else:
            query += f'&type={type}'
    if gpu is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None and type is None:
            query += f'?gpu={gpu}'
        else:
            query += f'&gpu={gpu}'
    if osg is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None and type is None and gpu is None:
            query += f'?osg={osg}'
        else:
            query += f'&osg={osg}'
    if alluxio is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None and type is None and gpu is None and osg is None:
            query += f'?alluxio={alluxio}'
        else:
            query += f'&alluxio={alluxio}'
    response = requests.get(query)
    if response.status_code == 200:
        site_list = response.json()
    return site_list


def delete_site(site_id):
    """
    Delete a site from the VDC API.

    Parameters
    ----------
    site_id : str
        The ID of the site to delete.
    
    Returns
    -------
    response : requests.models.Response
        The response from the VDC API.
    """
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}/{site_id}'
    response = requests.delete(query)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting link: {response.status_code}')


def add_site(site_info):
    """
    Add a site to the VDC API.

    Parameters
    ----------
    site_info : dict
        The site information to add.
    
    Returns
    -------
    site_info : dict
        The site information added.
    """
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}'
    response = requests.post(query, json=site_info)
    site_info = response.json()
    return site_info


def update_site(site_id, site_info):
    """
    Update a site in the VDC API.

    Parameters
    ----------
    site_id : str
        The ID of the site to update.
    site_info : dict
        The site information to update.
    
    Returns
    -------
    site_info : dict
        The site information updated.
    """
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}/{site_id}'
    response = requests.put(query, json=site_info)
    site_info = response.json()
    return site_info

==> vdcpy-0.0.11.tar.gz: vdcpy-0.0.11/vdcpy/site.py <==
import requests

import vdcpy.config as config


def get_sites(
    site_id=None, name=None, num=None, description=None, logo=None, host=None,
    slots=None, hub=None, type=None, gpu=None, osg=None, alluxio=None):
    """
    Get a list of sites from the VDC API.

    Parameters
    ----------
    site_id : str
        The ID of the site to retrieve.
    name : str
        The name of the site to retrieve.
    num : str
        The number of the site to retrieve.
    description : str
        The description of the site to retrieve.
    logo : str
        The logo of the site to retrieve.
    host : str
        The host of the site to retrieve.
    slots : str
        The slots of the site to retrieve.
    hub : str
        The hub of the site to retrieve.
    type : str
        The type of the site to retrieve.
    gpu : str
        The GPU of the site to retrieve.
    osg : str
        The OSG of the site to retrieve.
    alluxio : str
        The alluxio of the site to retrieve.
    
    Returns
    -------
    site_list : list
        A list of sites.
    """
    site_list = []
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}'
    if site_id is not None:
        query += f'?id={site_id}'
    if name is not None:
        if site_id is None:
            query += f'?name={name}'
        else:
            query += f'&name={name}'
    if num is not None:
        if site_id is None:
            query += f'?name={num}'
        else:
            query += f'&name={num}'
    if description is not None:
        if site_id is None and name is None:
            query += f'?description={description}'
        else:
            query += f'&description={description}'
    if logo is not None:
        if site_id is None and name is None and description is None:
            query += f'?logo={logo}'
        else:
            query += f'&logo={logo}'
    if host is not None:
        if site_id is None and name is None and description is None \
            and logo is None:
            query += f'?host={host}'
        else:
            query += f'&host={host}'
    if slots is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None:
            query += f'?slots={slots}'
        else:
            query += f'&slots={slots}'
    if hub is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None:
            query += f'?hub={hub}'
        else:
            query += f'&hub={hub}'
    if type is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None:
            query += f'?type={type}'
        else:
            query += f'&type={type}'
    if gpu is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None and type is None:
            query += f'?gpu={gpu}'
        else:
            query += f'&gpu={gpu}'
    if osg is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None and type is None and gpu is None:
            query += f'?osg={osg}'
        else:
            query += f'&osg={osg}'
    if alluxio is not None:
        if site_id is None and name is None and description is None \
            and logo is None and host is None and slots is None \
            and hub is None and type is None and gpu is None and osg is None:
            query += f'?alluxio={alluxio}'
        else:
            query += f'&alluxio={alluxio}'
    response = requests.get(query, timeout=5)
    if response.status_code == 200:
        site_list = response.json()
    
    site_list_copy = site_list.copy()
    for site_info in site_list_copy:
        if site_info['name'] in config.EXCLUDE_SITE:
            site_list.remove(site_info)

    if config.API_URL == 'http://DESKTOP-OMHH7GT:5000':
        site_list.append(
            {
                'host': 'DESKTOP-OMHH7GT',
                'name': 'localhost'
            }
        )

    return site_list


def delete_site(site_id, auth_token=None):
    """
    Delete a site from the VDC API.

    Parameters
    ----------
    site_id : str
        The ID of the site to delete.
    auth_token : str
        The authentication token to use.
    
    Returns
    -------
    response : requests.models.Response
        The response from the VDC API.
    """
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}/{site_id}'
    if auth_token is not None:
        headers = {'Authorization': auth_token}
    else:
        headers = None
    response = requests.delete(query, headers=headers)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting link: {response.status_code}')


def add_site(site_info, auth_token=None):
    """
    Add a site to the VDC API.

    Parameters
    ----------
    site_info : dict
        The site information to add.
    auth_token : str
        The authentication token to use.
    
    Returns
    -------
    site_info : dict
        The site information added.
    """
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}'
    if auth_token is not None:
        headers = {'Authorization': auth_token}
    else:
        headers = None
    response = requests.post(query, json=site_info, headers=headers)
    site_info = response.json()
    return site_info


def update_site(site_id, site_info, auth_token=None):
    """
    Update a site in the VDC API.

    Parameters
    ----------
    site_id : str
        The ID of the site to update.
    site_info : dict
        The site information to update.
    auth_token : str
        The authentication token to use.
    
    Returns
    -------
    site_info : dict
        The site information updated.
    """
    query = f'{config.API_URL}/{config.SITE_NAMESPACE}/{site_id}'
    if auth_token is not None:
        headers = {'Authorization': auth_token}
    else:
        headers = None
    response = requests.put(query, json=site_info, headers=headers)
    site_info = response.json()
    return site_info
